\name{OA}
\alias{OA}
\alias{OA.default}
\alias{print.OA}
\alias{summary.OA}
\alias{plot.OA}

\title{Optimal combination of number of participants and number of repeated measurements in longitudinal studies with time-varying exposure.}

\description{This function computes the optimal combination of number of participants and number of repeated measurements in longitudinal studies with fixed follow-up duration such that it maximizes the power to detect the effect under the alternative hypothesis without exceeding a fixed budget or it minimizes the cost of the study while achieving a certain target power. The response variable is assumed to be continuous and the exposure of interest is assumed to be binary and possibly time-varying.}

\usage{
OA(target, pattern, rMax = 20, theta = NULL, rho = NULL, sigma2, rhoe = NULL, pe0,
      per = NULL, piM = NULL, kappa = NULL, budget = NULL, c1, reqPower = NULL,
      beta, alpha = 0.05)


\method{OA}{default}(target, pattern, rMax = 20, theta = NULL, rho = NULL, sigma2, rhoe = NULL, pe0,
      per = NULL, piM = NULL, kappa = NULL, budget = NULL, c1, reqPower = NULL,
      beta, alpha = 0.05)
\method{print}{OA}(x, ...)
\method{summary}{OA}(object, ...)
\method{plot}{OA}(x, Ncex = 0.7, ...)
}

\arguments{
  \item{target}{character: "maxPower" for maximizing the power or "minCost" for minimizing the financial cost of the study.}
  \item{pattern}{character: two possible response patterns under the alternative hypothesis are allowed. "CMD" assumes an acute and transient exposure effect while "LDD" assumes a cumulative exposure effect, i.e., an exposure-time interaction.}
  \item{rMax}{maximum value of the number of repeated measurements evaluated. See 'Details' section.}
  \item{theta}{damping parameter of the damped exponential covariance structure of the response. See 'Details' section.}
  \item{rho}{correlation between the first and the last measurements of the response. See 'Details' section.}
  \item{sigma2}{residual variance. See 'Details' section.}
  \item{rhoe}{intraclass correlation of the exposure. See 'Details' section.}
  \item{pe0}{exposure prevalence at the first measurement. See 'Details' section.}
  \item{per}{exposure prevalence at the last measurement. See 'Details' section.}
  \item{piM}{fraction of individuals lost at the end of the study. See 'Details' section.}
  \item{kappa}{ratio between the financial cost of the first measurement (including recruitment) and each of the subsequent ones.}
  \item{budget}{total budget for the study if \code{target} = "maxPower".}
  \item{c1}{cost of the first measurement (including recruitment).}
  \item{reqPower}{required power if \code{target} = "minCost".}
  \item{beta}{expected effect under the alternative hypothesis. See 'Details' section.}
  \item{alpha}{significance level.}
  \item{x}{object of class 'OA'.}
  \item{object}{object of class 'OA'.}
  \item{Ncex}{font size for N values in the plot. Default is 0.7.}
  \item{...}{further arguments for print, plot or summary functions.}
}
\details{
The response covariance structure is assumed damped exponential, whose covariance matrix has diagonal elements \code{sigma}^2 and off-diagonal [j, j'] elements, \code{sigma2}\code{rho}^[(|j'-j|/r)^\code{theta}], where \code{sigma2} is the residual variance, \code{rho} is the correlation between the first and the last response measurements, \code{theta} in [0, 1] is the damping parameter and (r + 1) is the total number of measurements per participant. This covariance structure becomes compound symmetry if \code{theta}=0 and first order autoregressive if \code{theta}=1.

The intraclass correlation of exposure is defined as rhoe = (sum(SigmaE) - Tr(SigmaE))/(r Tr(SigmaE)) where sum() and Tr() denote the sum of the elements and the trace of a matrix respectively, and SigmaE is the covariance matrix of the exposure. rhoe can be interpreted as an index of similarity or agreement between each subject's exposure in the different time periods. If rhoe=1, the exposure is time-invariant.

The exposure prevalence is assumed to vary linearly from \code{pe0} at the first measurement to \code{per} at the last measurement. If \code{per} is omitted, the exposure prevalence is assumed time-invariant.

The dropout pattern is assumed to be monotone, i.e. losing one individual measurement implies losing all the subsequent measurements of that individual. No missing data at the first measurement is assumed.

If the response pattern is "CMD", \code{beta} can be interpreted as the expected difference in the mean of the response variable, at any time point, between exposed and non exposed. If the response pattern is "LDD", \code{beta} can be interpreted as the expected difference in the mean of the response variable between the worst exposure pattern (i.e., exposed at all measurements) and non-exposed, at the end of follow-up.

Note that the value of \code{rMax} exponentially increases the computational time.}
\value{
  \item{roptreal}{real solution to the problem.}
  \item{ropt}{optimal number of repeated measurements (i.e., the optimal total number of measurements is \code{ropt} + 1) constrained to be not greater than \code{rMax}.}
  \item{Nopt}{optimal number of participants.}
  \item{maxPower}{maximized power if \code{target} = "maxPower".}
  \item{minCost}{minimized financial cost if \code{target} = "minCost".}
  \item{cost}{needed cost if \code{target} = "maxPower".}
  \item{power}{achieved power if \code{target} = "minCost".}
  \item{sdBeta}{standard error of \code{beta}.}
  \item{f}{data.frame with power and sample size calculations for each value of the number of repeated measurements from 1 to \code{rMax}.}
  \item{parameters}{input parameters.}
}

\references{
Barrera-Gomez J, Spiegelman D, Basagana X. Optimal combination of number of  participants and number of repeated measurements in longitudinal studies with time-varying exposure. Statistics in Medicine [Epub ahead of print]. 
}

\examples{
# Maximizing power under "CMD" pattern of the response:
ex1 <- OA(target = "maxPower", pattern = "CMD", rMax = 20, theta = 0.5, rho = 0.7,
               sigma2 = 1, rhoe = 0.2, pe0 = 0.2, per = 0.3, piM = 0.2, kappa = 3, budget = 40,
               c1 = 1, beta = -0.3, alpha = 0.05)
ex1
summary(ex1)
plot(ex1)

# Minimizing cost under "LDD" pattern:
ex2 <- OA(target = "minCost", pattern = "LDD", rMax = 20, theta = 0, rho = 0.6,
               sigma2 = 1, rhoe = 0.6, pe0 = 0.2, per = 0.2, piM = 0.2, kappa = 3,
               reqPower = 0.8, c1 = 1, beta = 0.8, alpha = 0.05)
ex2
summary(ex2)
plot(ex2)

# Particular cases: power and sample size calculations in a cross-sectional
# study (r = 0 and pattern = "CMD"):
# Power:
ex3 <- OA(target = "maxPower", pattern = "CMD", rMax = 0, sigma2 = 1, pe0 = 0.2,
               budget = 400, c1 = 1, beta = -0.3, alpha = 0.05)
ex3
summary(ex3)
plot(ex3)

# Sampe size:
ex4 <- OA(target = "minCost", pattern = "CMD", rMax = 0, sigma2 = 1, pe0 = 0.2,
               reqPower = 0.8, c1 = 2.5, beta = 0.8, alpha = 0.05)
ex4
summary(ex4)
plot(ex4)
}
